# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .copilot_config import CopilotConfig
import datetime as dt
from .identity import Identity
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class Copilot(UncheckedBaseModel):
    copilot_config: CopilotConfig
    last_updated_at: dt.datetime
    created_at: dt.datetime
    created_by: Identity
    last_updated_by: Identity
    revision_id: str
    copilot_id: str
    is_draft: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
