# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .number_config_default_value import NumberConfigDefaultValue
from .number_config_min_value import NumberConfigMinValue
from .number_config_max_value import NumberConfigMaxValue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class NumberConfig(UncheckedBaseModel):
    default_value: typing.Optional[NumberConfigDefaultValue] = None
    min_value: typing.Optional[NumberConfigMinValue] = None
    max_value: typing.Optional[NumberConfigMaxValue] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
